##Make inset maps

rm(list = ls())

pacman::p_load("rworldmap", 'sf', 'dplyr','ggplot2', 'cowplot', 'grid', 'gtable',
               'gridExtra')

myThemeStuff <- 
  theme(panel.background = element_rect(fill=NA),
        axis.line = element_line(color = 'black'),
        axis.text = element_text(color = "black", size = 12, family="sans"),
        axis.title = element_text(color = "black", size = 14, family = "sans"),
        legend.text = element_text(color = "black", size = 12, family="sans"), 
        legend.title = element_text(color = "black", size = 14, family="sans")
  )

#Make inset map of Africa and DRC

#Load African land boundaries
countries <- getMap(resolution = "low")
countries <- st_as_sf(countries)
countries <- filter(countries, continent == "Africa")

#Drop Islands
countries <- filter(countries, GEO3 != "Western Indian Ocean")

#Crop out islands
usebbox <- c(-19, -36, 54, 38)
names(usebbox) <- names(st_bbox(countries))

countries <- st_crop(countries, usebbox)

#Project
africa <- st_transform(countries,"+proj=moll +lon_0=0 +lat_0=0 +ellps=WGS84 +no_defs")

drc <- filter(africa, SOV_A3 == "COD") %>% 
  mutate(SOV_A3 = as.factor(SOV_A3))

inset1 <- ggplot() + 
  geom_sf(data = africa, col = NA) + 
  myThemeStuff + 
  geom_sf(data = drc, fill = 'darkgreen', col = NA) + 
  theme(axis.line = element_blank(), 
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        legend.position = "none", 
        legend.title.align = 0, 
        plot.margin=margin(l=0,unit="cm"))


#Make inset map of Kinshasa in DRC
kpt <-  c(15.313419, -4.325391) %>% t() %>% as.data.frame()
names(kpt) <- c("lon","lat")
kpt <- st_as_sf(kpt, coords = c("lon","lat"), crs = 4326) %>% 
  st_transform(st_crs(drc))

inset2 <- ggplot() + 
  myThemeStuff + 
  geom_sf(data = drc, col = NA) + 
  geom_sf(data = kpt, color = 'darkgreen', shape = 17) + 
  theme(axis.line = element_blank(), 
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        legend.position = "none", 
        legend.title.align = 0, 
        plot.margin=margin(l=0,unit="cm"))


# Open the PDF device
pdf("output/figures/figure1_inset_map.pdf", width = 1.85, height = 1.5, bg = "white")

# Combine the plots with plot_grid, ensuring correct relative widths
combined_plot <- plot_grid(
  inset1, inset2,
  ncol = 2,
  rel_widths = c(1, 2) # Keeping the left side twice as wide
)

# Print the combined plot to the PDF
print(combined_plot)

# Instead of using separate commands for the border, include it as part of the plot_grid
# This ensures it's considered part of the single high-level plot command
grid.rect(x = 0.5, y = 0.5, width = unit(1, "npc"), height = unit(1, "npc"), just = "centre", 
          gp = gpar(col = "black", fill = NA, lwd = 2))

# Close the PDF device, finalizing the single page output
dev.off()

