#Two panel figure: main demand-side experiment result and supply-side experiment result

rm(list = ls())

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr', 'xtable')

myThemeStuff <- 
  theme(panel.background = element_rect(fill=NA),
        axis.line = element_line(color = 'black'),
        axis.text = element_text(color = "black", size = 9, family="sans"),
        axis.title = element_text(color = "black", size = 14, family = "sans"),
        legend.text = element_text(color = "black", size = 12, family="sans"), 
        legend.title = element_text(color = "black", size = 14, family="sans")
  )


plotdf <- data.frame(experiment = c('demand', 'supply'), 
                     y = 0, #want plots to be horizontal
                     coef = c(-0.014225, 0.910258), 
                     se = c(0.016735, 0.573059) 
                     ) %>% 
  #95% confidence intervals
  mutate(ub = coef + se*qnorm(.975), 
         lb = coef - se*qnorm(.975))

demandresult <- ggplot(data = filter(plotdf, experiment == 'demand'), aes(x = coef, y = y)) + 
  geom_point(size = 3) + 
  geom_errorbar(aes(xmin = lb, xmax = ub), width = 0) + 
  myThemeStuff + 
  theme(axis.line.y = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks.y = element_blank(), 
        axis.title.y = element_blank()) + 
  geom_vline(aes(xintercept = 0), linetype = 'dashed') + 
  scale_x_continuous("", breaks = seq(from = -0.04, to = 0.01, by = 0.01), 
                     labels = c("-0.04", '0.03','-0.02', '-0.01', '0', '0.01'))

ggsave(filename = 'output/figures/figure_s1a.pdf',
       plot = demandresult,  height = 1.8, width = 3, units = 'in')



supplyresult <- ggplot(data = filter(plotdf, experiment == 'supply'), aes(x = coef, y = y)) + 
  geom_point(size = 3) + 
  geom_errorbar(aes(xmin = lb, xmax = ub), width = 0) + 
  myThemeStuff + 
  theme(axis.line.y = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks.y = element_blank(), 
        axis.title.y = element_blank()) + 
  geom_vline(aes(xintercept = 0), linetype = 'dashed') + 
  scale_x_continuous("", breaks = c( 0, 0.5, 1, 1.5, 2), 
                     labels = c('0', '0.5', '1', '1.5', '2'))

ggsave(filename = 'output/figures/figure_s1b.pdf',
       plot = supplyresult,  height = 1.8, width = 3, units = 'in')
