rm(list = ls())

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr', 'xtable')

#For making tables
formNum <- function(mynum, dig){
  
  roundcoef <- round(mynum, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundcoef))==0){
    roundcoef <- paste0(roundcoef, ".")
  }
  
  #Add an extra zero beyond the decimal point if needed to get same length
  #Only do if does not contain e- or e+ (scientific notation)
  if(grep("e",roundcoef) %>% length() == 0){
    roundcoef <- sapply(seq_len(length(roundcoef)), function(x){
      if(gsub(".*\\.","",roundcoef[x]) %>% nchar() < dig){
        #Needed length
        zerosneeded <- dig - gsub(".*\\.","",roundcoef[x]) %>% nchar()
        roundcoef[x] <- paste0(roundcoef[x],paste0(rep(0,zerosneeded),collapse=""))
      } else{
        roundcoef[x]
      }
    })
  }
  
  #Add commas if necessary
  roundcoef <- prettyNum(roundcoef, ",")
  
  return(roundcoef)
}

#Given se and number of digits to round to, 
#return formatted SE
formSE <- function(se, dig){
  
  #Round
  roundse <- round(se, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundse))==0){
    roundse <- paste0(roundse, ".")
  }
  
  #Add zeros if necessary
  roundse <- sapply(seq_len(length(roundse)), function(x){
    if(gsub(".*\\.","",roundse[x]) %>% nchar() < dig){
      #Needed length (could need one extra zero or two)
      zerosneeded <- dig - gsub(".*\\.","",roundse[x]) %>% nchar()
      roundse[x] <- paste0(roundse[x],paste0(rep(0,zerosneeded),collapse=""))
    } else{
      roundse[x]
    }
  })
  
  #Add commas if necessary
  roundse <- prettyNum(roundse, ",")
  
  #Add parentheses 
  roundse <- paste0("(",roundse,")")
  
  return(roundse)
}

#Format regression displaying only treatment coefficient
formHorizReg <- function(regobj, dig, depvar){
  
  coef <- formNum(regobj$coeftable["treated","Estimate"], dig)
  se <- formSE(regobj$coeftable["treated","Std. Error"], dig)
  p_val <- formNum(regobj$coeftable["treated","Pr(>|t|)"], dig)
  controlmean <- filter(dat, treated == 0) %>% pull(depvar) %>%
    mean() %>% formNum(dig)
  N <- regobj$nobs
  
  out <- c(controlmean, coef, se, p_val, N)
  
  return(out)
}

#created in make_coupon_data.R
load('data/analysis_data/coupon_data.Rdata')

controlvars <- c("restaurant", "days_bushmeat", "age", "male", "university", 
                 "educ_years", "salary", "business_owner")

#Now one balance regression for each control variable 
tab <- matrix(NA, ncol = 6, nrow = 9)

tab[1,] <- c("Dependent Variable", "Control Mean", "Treatment Difference", "Standard Error", "P-Value", "N")

tab[2:9,1] <- c("Restaurant Habit",  "Bushmeat Days",  
                 "Age",  "Male",  "University Graduate",  "Years of Education",  
                 "Salary Earner",  "Business Owner")

for(i in 1:length(controlvars)){
  
  regobj <- paste0(controlvars[i], " ~ treated") %>% 
    as.Formula() %>% 
    feols(data = dat, cluster = 'coupon_id_gen')
  
  tab[(i + 1), 2:6] <- formHorizReg(regobj, 3, controlvars[i])
  
}

myxtable <- xtable(tab)

align(myxtable) <- c("l","l",rep("c",5))

label(myxtable) <- "balance"

print(myxtable, floating = TRUE, caption.placement="top",sanitize.text.function = identity,
      include.colnames=FALSE, include.rownames=FALSE, table.placement="tb",
      hline.after=NULL,
      add.to.row=list(
        pos = list(0, 1, nrow(tab)),
        command = c(
          "\\toprule ",
          "\\midrule ", 
          "\\bottomrule "
        )),
      type = "latex", file="output/tables/table1.tex")

#Mean values across all subjects reported in main text 
for(i in controlvars){pull(dat, i) %>% mean() %>% print()}
