rm(list = ls())

pacman::p_load("dplyr","readr",'lubridate','ggplot2','haven','readxl','purrr',"Formula", 
               'fixest', 'stringr', 'xtable')

#For making tables
formNum <- function(mynum, dig){
  
  roundcoef <- round(mynum, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundcoef))==0){
    roundcoef <- paste0(roundcoef, ".")
  }
  
  #Add an extra zero beyond the decimal point if needed to get same length
  #Only do if does not contain e- or e+ (scientific notation)
  if(grep("e",roundcoef) %>% length() == 0){
    roundcoef <- sapply(seq_len(length(roundcoef)), function(x){
      if(gsub(".*\\.","",roundcoef[x]) %>% nchar() < dig){
        #Needed length
        zerosneeded <- dig - gsub(".*\\.","",roundcoef[x]) %>% nchar()
        roundcoef[x] <- paste0(roundcoef[x],paste0(rep(0,zerosneeded),collapse=""))
      } else{
        roundcoef[x]
      }
    })
  }
  
  #Add commas if necessary
  roundcoef <- prettyNum(roundcoef, ",")
  
  return(roundcoef)
}

#Given se and number of digits to round to, 
#return formatted SE
formSE <- function(se, dig){
  
  #Round
  roundse <- round(se, dig) %>% as.character()
  
  #If rounded to integer, need to add "." to end
  if(length(grep("\\.",roundse))==0){
    roundse <- paste0(roundse, ".")
  }
  
  #Add zeros if necessary
  roundse <- sapply(seq_len(length(roundse)), function(x){
    if(gsub(".*\\.","",roundse[x]) %>% nchar() < dig){
      #Needed length (could need one extra zero or two)
      zerosneeded <- dig - gsub(".*\\.","",roundse[x]) %>% nchar()
      roundse[x] <- paste0(roundse[x],paste0(rep(0,zerosneeded),collapse=""))
    } else{
      roundse[x]
    }
  })
  
  #Add commas if necessary
  roundse <- prettyNum(roundse, ",")
  
  #Add parentheses 
  roundse <- paste0("(",roundse,")")
  
  return(roundse)
}

#Given regression object, create formatted vector of coefficients and standard errors
formReg <- function(regobj, dig, depvar, fixedeffects){
  
  vec <- map(names(coefficients(regobj)), function(x){
    
    singlecoef <- formNum(coefficients(regobj)[x], dig)
    singlese <- formSE(se(regobj)[x], dig)
    c(singlecoef, singlese)
    
  }) %>% unlist()
  
  #Append to vec mean of dep var among control group, 
  #percent change treatment coefficient represents relative to this mean
  #and number of obs in regression
  controlmean <- filter(dat, treated == 0) %>% pull(depvar) %>%
    mean()
  #were table and date fixed effects included in the regression?
  indfe <- ifelse(fixedeffects == 1, "Yes", "No")
  
  percentchange <- (coefficients(regobj)["treated"] / controlmean) * 100
  
  vec <- c(vec, indfe,
           regobj$nobs,
           #formNum(controlmean, dig), 
           formNum(percentchange, 2))
  
  return(vec)
}

#created in make_coupon_data.R
load('data/analysis_data/coupon_data.Rdata')

#we only pre-specified fixed effects, not individual subject characteristics, because I think that's what Dhar et al (2022) did
controlvars <- " | interview_date_fe + table_fe"



##Sixth regression is social desirability bias

#Code 1 if subject gives socially desirable answer
dat <- mutate(dat, encouraged = if_else(
  (!is.na(f_1_1) & f_1_1 %in% c(4,5)) | 
    (!is.na(f_2_1_va2) & f_2_1_va2 %in% c(1, 2)), 
  1, 0
), resentful = if_else(
  (!is.na(f_1_2) & f_1_2 %in% c(4,5)) | 
    (!is.na(f_2_2_va2) & f_2_2_va2 %in% c(1, 2)), 
  1, 0
), givenup = if_else(
  (!is.na(f_1_3) & f_1_3 %in% c(4,5)) | 
    (!is.na(f_2_3_va2) & f_2_3_va2 %in% c(1, 2)), 
  1, 0
), rebel = if_else(
  (!is.na(f_1_4) & f_1_4 %in% c(4,5)) | 
    (!is.na(f_2_4_va2) & f_2_4_va2 %in% c(1, 2)), 
  1, 0
), listener = if_else(
  (!is.na(f_1_5) & f_1_5 %in% c(1, 2)) | 
    (!is.na(f_2_5_va2) & f_2_5_va2 %in% c(4, 5)), 
  1, 0
), advantage = if_else(
  (!is.na(f_1_6) & f_1_6 %in% c(4,5)) | 
    (!is.na(f_2_6_va2) & f_2_6_va2 %in% c(1, 2)), 
  1, 0
), mistake  = if_else(
  (!is.na(f_1_7) & f_1_7 %in% c(1, 2)) | 
    (!is.na(f_2_7_va2) & f_2_7_va2 %in% c(4, 5)), 
  1, 0
), geteven = if_else(
  (!is.na(f_1_8) & f_1_8 %in% c(4,5)) | 
    (!is.na(f_2_8_va2) & f_2_8_va2 %in% c(1, 2)), 
  1, 0
), courteous  = if_else(
  (!is.na(f_1_9) & f_1_9 %in% c(1, 2)) | 
    (!is.na(f_2_9_va2) & f_2_9_va2 %in% c(4, 5)), 
  1, 0
), irked  = if_else(
  (!is.na(f_1_10) & f_1_10 %in% c(1, 2)) | 
    (!is.na(f_2_10_va2) & f_2_10_va2 %in% c(4, 5)), 
  1, 0
), jealous = if_else(
  (!is.na(f_1_11) & f_1_11 %in% c(4,5)) | 
    (!is.na(f_2_11_va2) & f_2_11_va2 %in% c(1, 2)), 
  1, 0
), irritated = if_else(
  (!is.na(f_1_12) & f_1_12 %in% c(4,5)) | 
    (!is.na(f_2_12_va2) & f_2_12_va2 %in% c(1, 2)), 
  1, 0
), hurt = if_else(
  (!is.na(f_1_13) & f_1_13 %in% c(4,5)) | 
    (!is.na(f_2_13_va2) & f_2_13_va2 %in% c(1, 2)), 
  1, 0
)
)

#standardized social desirability bias score
dat <- mutate(dat, soc_score = encouraged + resentful + givenup + rebel + 
                listener + advantage + mistake + geteven + courteous + irked + 
                jealous + irritated + hurt)

dat <- mutate(dat, soc_score = (soc_score - mean(dat$soc_score)) / 
                sd(dat$soc_score))

#negative coefficent on interaction term would mean treated subjects who are giving more 
#socially desirable answers are less likely to order bushmeat. zero coefficient would mean 
#social desirability bias/experimenter demand effects are not differentially changing what subjects
#order at restaurants

soc_mean <- feols(bushmeat_in_dish ~ treated + soc_score + treated*soc_score, data = dat, cluster = 'coupon_id_gen')

#ordered coefficient table
soc_mean_coef_table <- soc_mean$coeftable[c("treated","soc_score", "treated:soc_score", "(Intercept)"), c("Estimate", "Std. Error")]

soc_controls <- paste0("bushmeat_in_dish ~ treated + soc_score + treated*soc_score ", controlvars) %>% as.Formula() %>% 
  feols(data = dat, cluster = 'coupon_id_gen')

soc_controls_coef_table <- soc_controls$coeftable[c("treated","soc_score", "treated:soc_score"), c("Estimate", "Std. Error")]

tab <- matrix(NA, nrow = 11, ncol = 3)

tab[1, ] <- c("", "(1)", "(2)")

tab[,1] <- c("", "Treatment", "", "Social Desirability", "", "Treatment$\\times$Social Desirability", "",
             "Intercept", "", "Date and Table Fixed Effects", "N")

tab[2:9,2] <- c(formNum(soc_mean_coef_table[1, 1], 3), 
                formSE(soc_mean_coef_table[1, 2], 3),
                formNum(soc_mean_coef_table[2, 1], 3), 
                formSE(soc_mean_coef_table[2, 2], 3), 
                formNum(soc_mean_coef_table[3, 1], 3), 
                formSE(soc_mean_coef_table[3, 2], 3),
                formNum(soc_mean_coef_table[4, 1], 3), 
                formSE(soc_mean_coef_table[4, 2], 3)
)

tab[2:7,3] <- c(formNum(soc_controls_coef_table[1, 1], 3), 
                formSE(soc_controls_coef_table[1, 2], 3),
                formNum(soc_controls_coef_table[2, 1], 3), 
                formSE(soc_controls_coef_table[2, 2], 3), 
                formNum(soc_controls_coef_table[3, 1], 3), 
                formSE(soc_controls_coef_table[3, 2], 3)
)

tab[10, 2:3] <- c("No", "Yes")
tab[11, 2:3] <- c(soc_mean$nobs, soc_controls$nobs)

myxtable <- xtable(tab)

align(myxtable) <- c("l","l",rep("c",2))

label(myxtable) <- "social_table"

print(myxtable, floating = TRUE, caption.placement="top",sanitize.text.function = identity,
      include.colnames=FALSE, include.rownames=FALSE, table.placement="tb",
      hline.after=NULL,
      add.to.row=list(
        pos = list(0, 1, 9, nrow(tab)),
        command = c(
          "\\toprule \\multicolumn{2}{c}{Dependent Variable: Ordered Bushmeat} \\\\ ",
          "\\midrule ",
          "\\midrule  ",
          "\\bottomrule "
        )),
      type = "latex", file="output/tables/table_s3.tex")
